@@ -12,20 +12,35 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import sys
+
+from shade import _log
+
+log = _log.setup_logging(__name__)
+
 
 class OpenStackCloudException(Exception):
+
     def __init__(self, message, extra_data=None):
         args = [message]
         if extra_data:
             args.append(extra_data)
         super(OpenStackCloudException, self).__init__(*args)
         self.extra_data = extra_data
+        self._inner_exception = sys.exc_info()
+        if self._inner_exception and self._inner_exception[1]:
+            log.error(message, exc_info=self._inner_exception)
 
     def __str__(self):
+        message = Exception.__str__(self)
         if self.extra_data is not None:
-            return "%s (Extra: %s)" % (
-                Exception.__str__(self), self.extra_data)
-        return Exception.__str__(self)
+            message = "%s (Extra: %s)" % (message, self.extra_data)
+        if (self._inner_exception and self._inner_exception[1]
+                and hasattr(self._inner_exception[1], 'message')):
+            message = "%s (Inner Exception: %s)" % (
+                message,
+                self._inner_exception[1].message)
+        return message
 
 
 class OpenStackCloudTimeout(OpenStackCloudException):
