@@ -12,7 +12,7 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from keystoneclient import auth as ksc_auth
+from keystoneauth1 import plugin as ksc_plugin
 
 import mock
 import testtools
@@ -29,7 +29,7 @@ class TestShadeOperator(base.TestCase):
 
     def setUp(self):
         super(TestShadeOperator, self).setUp()
-        self.cloud = shade.operator_cloud()
+        self.cloud = shade.operator_cloud(validate=False)
 
     def test_operator_cloud(self):
         self.assertIsInstance(self.cloud, shade.OperatorCloud)
@@ -527,6 +527,10 @@ class TestShadeOperator(base.TestCase):
 
     @mock.patch.object(shade.OperatorCloud, 'ironic_client')
     def test_unregister_machine(self, mock_client):
+        class fake_node:
+            provision_state = 'available'
+
+        mock_client.node.get.return_value = fake_node
         nics = [{'mac': '00:00:00:00:00:00'}]
         uuid = "00000000-0000-0000-0000-000000000000"
         self.cloud.unregister_machine(nics, uuid)
@@ -534,8 +538,34 @@ class TestShadeOperator(base.TestCase):
         self.assertTrue(mock_client.port.delete.called)
         self.assertTrue(mock_client.port.get_by_address.called)
 
+    @mock.patch.object(shade.OperatorCloud, 'ironic_client')
+    def test_unregister_machine_unavailable(self, mock_client):
+        invalid_states = ['active', 'cleaning', 'clean wait', 'clean failed']
+        nics = [{'mac': '00:00:00:00:00:00'}]
+        uuid = "00000000-0000-0000-0000-000000000000"
+        for state in invalid_states:
+            class fake_node:
+                provision_state = state
+
+            mock_client.node.get.return_value = fake_node
+            self.assertRaises(
+                exc.OpenStackCloudException,
+                self.cloud.unregister_machine,
+                nics,
+                uuid)
+            self.assertFalse(mock_client.node.delete.called)
+            self.assertFalse(mock_client.port.delete.called)
+            self.assertFalse(mock_client.port.get_by_address.called)
+            self.assertTrue(mock_client.node.get.called)
+            mock_client.node.reset_mock()
+            mock_client.node.reset_mock()
+
     @mock.patch.object(shade.OperatorCloud, 'ironic_client')
     def test_unregister_machine_timeout(self, mock_client):
+        class fake_node:
+            provision_state = 'available'
+
+        mock_client.node.get.return_value = fake_node
         nics = [{'mac': '00:00:00:00:00:00'}]
         uuid = "00000000-0000-0000-0000-000000000000"
         self.assertRaises(
@@ -738,7 +768,7 @@ class TestShadeOperator(base.TestCase):
     def test_get_session_endpoint_identity(self, session_mock):
         self.cloud.get_session_endpoint('identity')
         session_mock.get_endpoint.assert_called_with(
-            interface=ksc_auth.AUTH_INTERFACE)
+            interface=ksc_plugin.AUTH_INTERFACE)
 
     @mock.patch.object(shade.OpenStackCloud, 'keystone_session')
     def test_has_service_no(self, session_mock):
